#!/usr/bin/env python

# ***** BEGIN LICENSE BLOCK *****
# Version: MPL 1.1/GPL 2.0/LGPL 2.1
# 
# The contents of this file are subject to the Mozilla Public License Version
# 1.1 (the "License"); you may not use this file except in compliance with
# the License. You may obtain a copy of the License at
# http://www.mozilla.org/MPL/
# 
# Software distributed under the License is distributed on an "AS IS" basis,
# WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
# for the specific language governing rights and limitations under the
# License.
# 
# The Original Code is mozilla.org code.
# 
# The Initial Developer of the Original Code is
# Mozilla.org.
# Portions created by the Initial Developer are Copyright (C) 2010
# the Initial Developer. All Rights Reserved.
# 
# Contributor(s):
#     Jeff Hammel <jhammel@mozilla.com>     (Original author)
# 
# Alternatively, the contents of this file may be used under the terms of
# either of the GNU General Public License Version 2 or later (the "GPL"),
# or the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
# in which case the provisions of the GPL or the LGPL are applicable instead
# of those above. If you wish to allow use of your version of this file only
# under the terms of either the GPL or the LGPL, and not to allow others to
# use your version of this file under the terms of the MPL, indicate your
# decision by deleting the provisions above and replace them with the notice
# and other provisions required by the GPL or the LGPL. If you do not delete
# the provisions above, a recipient may use your version of this file under
# the terms of any one of the MPL, the GPL or the LGPL.
# 
# ***** END LICENSE BLOCK *****

import os
import time
from profilemanager import ProfileManager

# Get the path to the test profiles.ini file:
from pkg_resources import resource_filename
profiles_dir = os.path.join('tests', 'profiles')
path = os.path.join(profiles_dir, 'profiles.ini')
profiles = resource_filename('profilemanager', path)
profiles_dir = resource_filename('profilemanager', profiles_dir)
assert os.path.exists(profiles), '%s does not exist' % profiles
assert os.path.exists(profiles_dir), '%s does not exist' % profiles_dir

# Instatiate a ProfileManager:
manager = ProfileManager(profiles)

# Remove any profiles that didn't get cleaned up:
profiles_dict = manager.profiles_dict()
for profile in profiles_dict:
  manager.remove(profile)
assert os.listdir(profiles_dir) == ['profiles.ini'], 'profiles_dir isnt empty except profiles.ini'
assert file(profiles).read().strip() == '[General]', 'profiles.ini isnt nearly empty'

# Create a new profile:
profiledir = manager.new('testprofile')
assert profiledir.endswith('.testprofile'), 'profiledir should end with testprofile, instead it is %s' % profiledir
assert manager.list() == ['testprofile']

# Clone the profile:
manager.clone('testprofile', 'cloneprofile')
assert sorted(manager.list()) == ['cloneprofile', 'testprofile']
manager.remove('cloneprofile')

# Backup the profile
manager.backup('testprofile')
backups = manager.backups('testprofile')
assert len(backups) == 1, "Expected one backup, instead got %d" % len(backups)
assert backups[0][0].startswith('testprofile')
manager.restore('testprofile')
manager.restore('testprofile', delete=True)
backups = manager.backups('testprofile')
assert not backups
# TODO: test the backup with a populated profile

# Test dated backups
manager.backup('testprofile')
old_backups = manager.backups('testprofile')
assert len(old_backups) == 1, "Expected one backup, instead got %d" % len(old_backups)
old_time = int(time.time())
time.sleep(3)
manager.backup('testprofile')
new_backups = manager.backups('testprofile')
assert len(new_backups) == 2, "Expected two backups, instead got %d" % len(new_backups)
restore_time = old_time + 1
restored = manager.restore('testprofile', date=restore_time)
assert restored == old_backups[0], "Tried to restore from %d [%s], but got [%s]" % (restore_time, old_backups[0], restored)
# TODO: test with alternate forms of date

# Restore the newest profile
restored = manager.restore('testprofile')
assert restored != old_backups[0], "Tried to restore the newest but got the old one [%s]" % old_backups[0]
manager.restore('testprofile', delete=True)
manager.restore('testprofile', delete=True)
assert not manager.backups()
assert manager.list() == ['testprofile']

# Cleanup:
manager.remove('testprofile')
assert manager.list() == []
f = file(profiles, 'w')
print >> f, '[General]'
